Perform the motif adjacency matrix calculations for motif Mexpa
mam_Mexpa(adj_mat, motif_type, mam_weight_type, mam_method)A motif adjacency matrix.
Adjacency matrix from which to build the motif adjacency matrix.
Type of motif adjacency matrix to build.
The weighting scheme to use.
One of "unweighted", "mean" or "product".
Which formulation to use.
One of "dense" or "sparse".